package com.ruoyi.learn.mapper;

import java.util.List;
import com.ruoyi.learn.domain.LearnWrongDetail;

/**
 * 学生错题流水Mapper接口
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
public interface LearnWrongDetailMapper 
{
    /**
     * 查询学生错题流水
     * 
     * @param wrongDetailId 学生错题流水主键
     * @return 学生错题流水
     */
    public LearnWrongDetail selectLearnWrongDetailByWrongDetailId(Long wrongDetailId);

    /**
     * 查询学生错题流水列表
     * 
     * @param learnWrongDetail 学生错题流水
     * @return 学生错题流水集合
     */
    public List<LearnWrongDetail> selectLearnWrongDetailList(LearnWrongDetail learnWrongDetail);

    /**
     * 新增学生错题流水
     * 
     * @param learnWrongDetail 学生错题流水
     * @return 结果
     */
    public int insertLearnWrongDetail(LearnWrongDetail learnWrongDetail);

    /**
     * 修改学生错题流水
     * 
     * @param learnWrongDetail 学生错题流水
     * @return 结果
     */
    public int updateLearnWrongDetail(LearnWrongDetail learnWrongDetail);

    /**
     * 删除学生错题流水
     * 
     * @param wrongDetailId 学生错题流水主键
     * @return 结果
     */
    public int deleteLearnWrongDetailByWrongDetailId(Long wrongDetailId);

    /**
     * 批量删除学生错题流水
     * 
     * @param wrongDetailIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLearnWrongDetailByWrongDetailIds(Long[] wrongDetailIds);
}
